@@ -2,7 +2,6 @@ from .api import (
     ApplicationIn,
     ApplicationOut,
     DashboardAccessOut,
-    FetchOptions,
     ListResponseApplicationOut,
     ListResponseMessageOut,
     MessageIn,
@@ -16,7 +15,6 @@ __all__ = [
     "ApplicationIn",
     "ApplicationOut",
     "DashboardAccessOut",
-    "FetchOptions",
     "ListResponseApplicationOut",
     "ListResponseMessageOut",
     "MessageIn",
@@ -26,3 +24,5 @@ __all__ = [
     "Webhook",
     "WebhookVerificationError",
 ]
+
+__version__ = "0.30.0"
