@@ -1,32 +1,34 @@
 import typing as t
 from contextlib import contextmanager
 from dataclasses import asdict, dataclass
+from datetime import datetime
 
-from .openapi_client.api.application_api import (
-    ApplicationApi,
-    ApplicationIn,
-    ApplicationOut,
-    ListResponseApplicationOut,
-)
-from .openapi_client.api.authentication_api import AuthenticationApi, DashboardAccessOut
-from .openapi_client.api.endpoint_api import (
-    EndpointApi,
-    EndpointIn,
-    EndpointOut,
-    EndpointSecretOut,
-    ListResponseEndpointOut,
-)
-from .openapi_client.api.event_type_api import (
-    EventTypeApi,
-    EventTypeIn,
-    EventTypeOut,
-    EventTypeUpdate,
-    ListResponseEventTypeOut,
-)
-from .openapi_client.api.message_api import ListResponseMessageOut, MessageApi, MessageIn, MessageOut
-from .openapi_client.api.message_attempt_api import ListResponseMessageAttemptOut, MessageAttemptApi, MessageAttemptOut
+from .openapi_client.api.application_api import ApplicationApi
+from .openapi_client.api.authentication_api import AuthenticationApi
+from .openapi_client.api.endpoint_api import EndpointApi
+from .openapi_client.api.event_type_api import EventTypeApi
+from .openapi_client.api.message_api import MessageApi
+from .openapi_client.api.message_attempt_api import MessageAttemptApi
 from .openapi_client.api_client import ApiClient
 from .openapi_client.configuration import Configuration
+from .openapi_client.model.application_in import ApplicationIn
+from .openapi_client.model.application_out import ApplicationOut
+from .openapi_client.model.dashboard_access_out import DashboardAccessOut
+from .openapi_client.model.endpoint_in import EndpointIn
+from .openapi_client.model.endpoint_out import EndpointOut
+from .openapi_client.model.endpoint_secret_out import EndpointSecretOut
+from .openapi_client.model.endpoint_update import EndpointUpdate
+from .openapi_client.model.event_type_in import EventTypeIn
+from .openapi_client.model.event_type_out import EventTypeOut
+from .openapi_client.model.event_type_update import EventTypeUpdate
+from .openapi_client.model.list_response_application_out import ListResponseApplicationOut
+from .openapi_client.model.list_response_endpoint_out import ListResponseEndpointOut
+from .openapi_client.model.list_response_event_type_out import ListResponseEventTypeOut
+from .openapi_client.model.list_response_message_attempt_out import ListResponseMessageAttemptOut
+from .openapi_client.model.list_response_message_out import ListResponseMessageOut
+from .openapi_client.model.message_attempt_out import MessageAttemptOut
+from .openapi_client.model.message_in import MessageIn
+from .openapi_client.model.message_out import MessageOut
 from .openapi_client.model.message_status import MessageStatus
 
 DEFAULT_SERVER_URL = "https://api.svix.com"
@@ -39,7 +41,7 @@ class SvixOptions:
 
 
 @dataclass
-class FetchOptions:
+class ListOptions:
     iterator: t.Optional[str] = None
     limit: t.Optional[int] = None
 
@@ -48,8 +50,31 @@ class FetchOptions:
 
 
 @dataclass
-class FetchOptionsMessageAttempt(FetchOptions):
+class MessageListOptions(ListOptions):
+    event_types: t.Optional[t.List[str]] = None
+    before: t.Optional[datetime] = None
+
+
+@dataclass
+class ApplicationListOptions(ListOptions):
+    pass
+
+
+@dataclass
+class EventTypeListOptions(ListOptions):
+    with_content: t.Optional[bool] = None
+
+
+@dataclass
+class EndpointListOptions(ListOptions):
+    pass
+
+
+@dataclass
+class MessageAttemptListOptions(ListOptions):
     status: t.Optional[MessageStatus] = None
+    event_types: t.Optional[t.List[str]] = None
+    before: t.Optional[datetime] = None
 
 
 ApiClass = t.TypeVar(
@@ -68,6 +93,11 @@ class ApiBase(t.Generic[ApiClass]):
     @contextmanager
     def _api(self) -> t.Generator[ApiClass, None, None]:
         with ApiClient(self._configuration) as api_client:  # type: ignore
+
+            from . import __version__
+
+            api_client.user_agent = f"svix-libs/{__version__}/python"
+
             yield t.cast(t.Any, self._ApiClass(api_client))
 
 
@@ -88,7 +118,7 @@ class Authentication(ApiBase[AuthenticationApi]):
 class Application(ApiBase[ApplicationApi]):
     _ApiClass = ApplicationApi
 
-    def list(self, options: FetchOptions = FetchOptions()) -> ListResponseApplicationOut:
+    def list(self, options: ApplicationListOptions = ApplicationListOptions()) -> ListResponseApplicationOut:
         with self._api() as api:
             return api.list_applications_api_v1_app_get(**options.to_dict(), _check_return_type=False)
 
@@ -114,7 +144,7 @@ class Application(ApiBase[ApplicationApi]):
 class Endpoint(ApiBase[EndpointApi]):
     _ApiClass = EndpointApi
 
-    def list(self, app_id: str, options: FetchOptions = FetchOptions()) -> ListResponseEndpointOut:
+    def list(self, app_id: str, options: EndpointListOptions = EndpointListOptions()) -> ListResponseEndpointOut:
         with self._api() as api:
             return api.list_endpoints_api_v1_app_app_id_endpoint_get(
                 app_id=app_id, **options.to_dict(), _check_return_type=False
@@ -132,10 +162,10 @@ class Endpoint(ApiBase[EndpointApi]):
                 app_id=app_id, endpoint_id=endpoint_id, _check_return_type=False
             )
 
-    def update(self, app_id: str, endpoint_id: str, endpoint_in: EndpointIn) -> EndpointOut:
+    def update(self, app_id: str, endpoint_id: str, endpoint_update: EndpointUpdate) -> EndpointOut:
         with self._api() as api:
             return api.update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put(
-                app_id=app_id, endpoint_id=endpoint_id, endpoint_in=endpoint_in, _check_return_type=False
+                app_id=app_id, endpoint_id=endpoint_id, endpoint_update=endpoint_update, _check_return_type=False
             )
 
     def delete(self, app_id: str, endpoint_id: str) -> None:
@@ -154,7 +184,7 @@ class Endpoint(ApiBase[EndpointApi]):
 class EventType(ApiBase[EventTypeApi]):
     _ApiClass = EventTypeApi
 
-    def list(self, options: FetchOptions = FetchOptions()) -> ListResponseEventTypeOut:
+    def list(self, options: EventTypeListOptions = EventTypeListOptions()) -> ListResponseEventTypeOut:
         with self._api() as api:
             return api.list_event_types_api_v1_event_type_get(**options.to_dict(), _check_return_type=False)
 
@@ -178,7 +208,7 @@ class EventType(ApiBase[EventTypeApi]):
 class Message(ApiBase[MessageApi]):
     _ApiClass = MessageApi
 
-    def list(self, app_id: str, options: FetchOptions = FetchOptions()) -> ListResponseMessageOut:
+    def list(self, app_id: str, options: MessageListOptions = MessageListOptions()) -> ListResponseMessageOut:
         with self._api() as api:
             return api.list_messages_api_v1_app_app_id_msg_get(
                 app_id=app_id, **options.to_dict(), _check_return_type=False
@@ -201,7 +231,7 @@ class MessageAttempt(ApiBase[MessageAttemptApi]):
     _ApiClass = MessageAttemptApi
 
     def list(
-        self, app_id: str, msg_id: str, options: FetchOptionsMessageAttempt = FetchOptionsMessageAttempt()
+        self, app_id: str, msg_id: str, options: MessageAttemptListOptions = MessageAttemptListOptions()
     ) -> ListResponseMessageAttemptOut:
         with self._api() as api:
             return api.list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get(
@@ -273,7 +303,9 @@ __all__ = [
     "MessageAttemptOut",
     "MessageStatus",
     "SvixOptions",
-    "FetchOptions",
-    "FetchOptionsMessageAttempt",
+    "ApplicationListOptions",
+    "EventTypeListOptions",
+    "EndpointListOptions",
+    "MessageAttemptListOptions",
     "Svix",
 ]
