@@ -12,11 +12,21 @@
 from svix.openapi_client.model.application_in import ApplicationIn
 from svix.openapi_client.model.application_out import ApplicationOut
 from svix.openapi_client.model.dashboard_access_out import DashboardAccessOut
+from svix.openapi_client.model.endpoint_created_event import EndpointCreatedEvent
+from svix.openapi_client.model.endpoint_created_event_data import EndpointCreatedEventData
+from svix.openapi_client.model.endpoint_deleted_event import EndpointDeletedEvent
+from svix.openapi_client.model.endpoint_deleted_event_data import EndpointDeletedEventData
+from svix.openapi_client.model.endpoint_disabled_event import EndpointDisabledEvent
+from svix.openapi_client.model.endpoint_disabled_event_data import EndpointDisabledEventData
 from svix.openapi_client.model.endpoint_in import EndpointIn
 from svix.openapi_client.model.endpoint_message_out import EndpointMessageOut
 from svix.openapi_client.model.endpoint_out import EndpointOut
 from svix.openapi_client.model.endpoint_secret_out import EndpointSecretOut
 from svix.openapi_client.model.endpoint_stats import EndpointStats
+from svix.openapi_client.model.endpoint_update import EndpointUpdate
+from svix.openapi_client.model.endpoint_updated_event_data import EndpointUpdatedEventData
+from svix.openapi_client.model.endpointd_updated_event import EndpointdUpdatedEvent
+from svix.openapi_client.model.event_example_in import EventExampleIn
 from svix.openapi_client.model.event_type_in import EventTypeIn
 from svix.openapi_client.model.event_type_out import EventTypeOut
 from svix.openapi_client.model.event_type_update import EventTypeUpdate
@@ -31,9 +41,14 @@ from svix.openapi_client.model.list_response_message_attempt_out import ListResp
 from svix.openapi_client.model.list_response_message_endpoint_out import ListResponseMessageEndpointOut
 from svix.openapi_client.model.list_response_message_out import ListResponseMessageOut
 from svix.openapi_client.model.message_attempt_endpoint_out import MessageAttemptEndpointOut
+from svix.openapi_client.model.message_attempt_exhausted_event import MessageAttemptExhaustedEvent
+from svix.openapi_client.model.message_attempt_exhausted_event_data import MessageAttemptExhaustedEventData
+from svix.openapi_client.model.message_attempt_failed_event import MessageAttemptFailedEvent
 from svix.openapi_client.model.message_attempt_out import MessageAttemptOut
+from svix.openapi_client.model.message_attempt_trigger_type import MessageAttemptTriggerType
 from svix.openapi_client.model.message_endpoint_out import MessageEndpointOut
 from svix.openapi_client.model.message_in import MessageIn
 from svix.openapi_client.model.message_out import MessageOut
 from svix.openapi_client.model.message_status import MessageStatus
 from svix.openapi_client.model.validation_error import ValidationError
+from svix.openapi_client.model.webhook_types import WebhookTypes
